diff --git a/CMakeLists.txt b/CMakeLists.txt
index 54c62782bf9ddbe9ab9f9f59abcf69d7f01e26d0..99fdff720552ea123f5b8d1f6de3836372bd9609 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -2,7 +2,7 @@
 # general stuff
 cmake_minimum_required(VERSION 2.6)
 set(ProjectName            "DuMuX")
-set(ProjectVersion         "1.1svn")
+set(ProjectVersion         "2.1svn")
 set(ProjectMaintainer      "Bernd Flemisch")
 set(ProjectMaintainerEmail "Bernd.Flemisch_at_iws dot uni-stuttgart dot de")
 project(${ProjectName} CXX)
diff --git a/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh b/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
index d9ff769481be4aa9b6de3de3f595a6eed4139956..52958cc41bd76b24980854cda0f78134138426d5 100644
--- a/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
+++ b/appl/lecture/msm/1p2cvs2p/lensproblem2p.hh
@@ -79,7 +79,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(LensProblem2p, NonWettingPhase)
+SET_PROP(LensProblem2p, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/appl/lecture/msm/buckleyleverett/buckleyleverett_ff.cc b/appl/lecture/msm/buckleyleverett/buckleyleverett_ff.cc
index a94af08d2f0a14781300e3cff65bdd325c5d6799..8df5c5d9d6a3f0fa48a92fc7727dd8f65bdc482e 100644
--- a/appl/lecture/msm/buckleyleverett/buckleyleverett_ff.cc
+++ b/appl/lecture/msm/buckleyleverett/buckleyleverett_ff.cc
@@ -112,13 +112,13 @@ int main(int argc, char** argv)
         ////////////////////////////////////////////////////////////
 
         typedef GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-        typedef GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+        typedef GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
         WettingPhase::Component::setViscosity(Params::tree().get<double>("Fluid.viscosityW"));
-        NonWettingPhase::Component::setViscosity(Params::tree().get<double>("Fluid.viscosityNW"));
+        NonwettingPhase::Component::setViscosity(Params::tree().get<double>("Fluid.viscosityNW"));
 
         WettingPhase::Component::setDensity(Params::tree().get<double>("Fluid.densityW"));
-        NonWettingPhase::Component::setDensity(Params::tree().get<double>("Fluid.densityNW"));
+        NonwettingPhase::Component::setDensity(Params::tree().get<double>("Fluid.densityNW"));
 
         TimeManager timeManager;
         Problem problem(timeManager, grid.leafView(), lowerLeft, upperRight);
diff --git a/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh b/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
index 5712c4fcaf39ae920de17917f4655d6124cba601..60f89a26b454d990bc9da70c6a4e95ca07599886 100644
--- a/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
+++ b/appl/lecture/msm/buckleyleverett/buckleyleverettproblem.hh
@@ -87,7 +87,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(BuckleyLeverettProblem, NonWettingPhase)
+SET_PROP(BuckleyLeverettProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/appl/lecture/msm/mcwhorter/mcwhorter_ff.cc b/appl/lecture/msm/mcwhorter/mcwhorter_ff.cc
index d1e4a4e8d40f45bb6230e12f5a9b1cad99b3a1ab..68b2229b8d8f1d23d4bbd8e9ce47f7e2ff7ef49b 100644
--- a/appl/lecture/msm/mcwhorter/mcwhorter_ff.cc
+++ b/appl/lecture/msm/mcwhorter/mcwhorter_ff.cc
@@ -90,10 +90,10 @@ int main(int argc, char** argv)
         ////////////////////////////////////////////////////////////
 
         typedef GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-        typedef GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+        typedef GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
         WettingPhase::Component::setViscosity(Params::tree().get<double>("fluid.viscosityW"));
-        NonWettingPhase::Component::setViscosity(Params::tree().get<double>("fluid.viscosityNW"));
+        NonwettingPhase::Component::setViscosity(Params::tree().get<double>("fluid.viscosityNW"));
 
         TimeManager timeManager;
         Problem problem(timeManager, grid.leafView(), lowerLeft, upperRight);
diff --git a/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh b/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
index 0f6bddf85d9a24af8d6117d69496ed4f91ab770f..bd5ac6935b57ecfc2de3e48552da469277696e45 100644
--- a/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
+++ b/appl/lecture/msm/mcwhorter/mcwhorterproblem.hh
@@ -84,7 +84,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(McWhorterProblem, NonWettingPhase)
+SET_PROP(McWhorterProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/dumux/boxmodels/2p/2pproperties.hh b/dumux/boxmodels/2p/2pproperties.hh
index 76921a549425661f81e99343d17a577c4fa7109f..3464af4803752c72c85084afb5928493b71a2e4b 100644
--- a/dumux/boxmodels/2p/2pproperties.hh
+++ b/dumux/boxmodels/2p/2pproperties.hh
@@ -67,7 +67,7 @@ NEW_PROP_TAG(SpatialParameters); //!< The type of the spatial parameters object
 NEW_PROP_TAG(MaterialLaw);   //!< The material law which ought to be used (extracted from the spatial parameters)
 NEW_PROP_TAG(MaterialLawParams); //!< The context material law (extracted from the spatial parameters)
 NEW_PROP_TAG(WettingPhase); //!< The wetting phase for two-phase models
-NEW_PROP_TAG(NonWettingPhase); //!< The non-wetting phase for two-phase models
+NEW_PROP_TAG(NonwettingPhase); //!< The non-wetting phase for two-phase models
 NEW_PROP_TAG(FluidSystem); //!<The fluid systems including the information about the phases
 NEW_PROP_TAG(FluidState); //!<The phases state
 NEW_PROP_TAG(EnableVelocityOutput); //!< Returns whether vertex velocity vectors are written into the vtk output
diff --git a/dumux/boxmodels/2p/2ppropertydefaults.hh b/dumux/boxmodels/2p/2ppropertydefaults.hh
index 5daa12e84b13a593ac7968580fdc50d95b61f931..d254c317d5b68517da0c579b954729beb010b6b2 100644
--- a/dumux/boxmodels/2p/2ppropertydefaults.hh
+++ b/dumux/boxmodels/2p/2ppropertydefaults.hh
@@ -98,7 +98,7 @@ public:
     typedef Dumux::LiquidPhase<Scalar, Dumux::NullComponent<Scalar> > type;
 };
 
-SET_PROP(BoxTwoP, NonWettingPhase)
+SET_PROP(BoxTwoP, NonwettingPhase)
 { private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
 public:
@@ -109,12 +109,12 @@ SET_PROP(BoxTwoP, FluidSystem)
 { private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
 public:
     typedef Dumux::FluidSystems::TwoPImmiscible<Scalar,
                                                 WettingPhase,
-                                                NonWettingPhase> type;
+                                                NonwettingPhase> type;
 };
 
 SET_PROP(BoxTwoP, FluidState)
diff --git a/dumux/boxmodels/richards/richardsproperties.hh b/dumux/boxmodels/richards/richardsproperties.hh
index 9ad8d8bf91a84428956a8abef256d01268a07889..2c1bdbce6c9c051f062dd10893851905d320db6a 100644
--- a/dumux/boxmodels/richards/richardsproperties.hh
+++ b/dumux/boxmodels/richards/richardsproperties.hh
@@ -59,7 +59,7 @@ NEW_PROP_TAG(MaterialLaw);   //!< The material law which ought to be used (by de
 NEW_PROP_TAG(MaterialLawParams); //!< The type of the parameter object for the material law (by default extracted from the spatial parameters)
 NEW_PROP_TAG(FluidSystem); //!< The fluid system to be used for the Richards model
 NEW_PROP_TAG(WettingPhase); //!< Fluid which represents the wetting phase
-NEW_PROP_TAG(NonWettingPhase); //!< Fluid which represents the non-wetting phase
+NEW_PROP_TAG(NonwettingPhase); //!< Fluid which represents the non-wetting phase
 NEW_PROP_TAG(EnableGravity); //!< Returns whether gravity is considered in the problem
 NEW_PROP_TAG(MassUpwindWeight); //!< The value of the weight of the upwind direction in the mass conservation equations
 // \}
diff --git a/dumux/decoupled/2p/2pproperties.hh b/dumux/decoupled/2p/2pproperties.hh
index d60acaa9f10e20780b64393454fa64b3896e25d0..a149830fca4f0d649a7a76af439680dc8406244a 100644
--- a/dumux/decoupled/2p/2pproperties.hh
+++ b/dumux/decoupled/2p/2pproperties.hh
@@ -95,7 +95,7 @@ NEW_PROP_TAG( EnableCompressibility)
 ;// !< Returns whether compressibility is allowed
 NEW_PROP_TAG( WettingPhase)
 ; //!< The wetting phase for two-phase models
-NEW_PROP_TAG( NonWettingPhase)
+NEW_PROP_TAG( NonwettingPhase)
 ; //!< The non-wetting phase for two-phase models
 NEW_PROP_TAG( FluidSystem )//!< Defines the fluid system
 ;
diff --git a/dumux/material/fluidsystems/2pimmisciblefluidsystem.hh b/dumux/material/fluidsystems/2pimmisciblefluidsystem.hh
index d2526698884e9b5c88c3aff104abfd84fcc259fb..0d6c76e91f057b036c738b681d957701cd623e5e 100644
--- a/dumux/material/fluidsystems/2pimmisciblefluidsystem.hh
+++ b/dumux/material/fluidsystems/2pimmisciblefluidsystem.hh
@@ -62,15 +62,15 @@ namespace FluidSystems {
  * An adapter class using Dumux::FluidSystem<TypeTag> is also provided
  * at the end of this file.
  */
-template <class Scalar, class WettingPhase, class NonWettingPhase>
+template <class Scalar, class WettingPhase, class NonwettingPhase>
 class TwoPImmiscible
-: public BaseFluidSystem<Scalar, TwoPImmiscible<Scalar, WettingPhase, NonWettingPhase> >
+: public BaseFluidSystem<Scalar, TwoPImmiscible<Scalar, WettingPhase, NonwettingPhase> >
 {
     // do not try to instanciate this class, it has only static members!
     TwoPImmiscible()
     {}
 
-    typedef TwoPImmiscible<Scalar, WettingPhase, NonWettingPhase> ThisType;
+    typedef TwoPImmiscible<Scalar, WettingPhase, NonwettingPhase> ThisType;
     typedef BaseFluidSystem<Scalar, ThisType> Base;
 public:
     /****************************************
@@ -108,7 +108,7 @@ public:
 
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::isLiquid();
-        return NonWettingPhase::isLiquid();
+        return NonwettingPhase::isLiquid();
     }
 
     /*!
@@ -147,7 +147,7 @@ public:
         // let the fluids decide
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::isCompressible();
-        return NonWettingPhase::isCompressible();
+        return NonwettingPhase::isCompressible();
     }
 
     /****************************************
@@ -173,7 +173,7 @@ public:
 
         if (compIdx == wCompIdx)
             return WettingPhase::name();
-        return NonWettingPhase::name();
+        return NonwettingPhase::name();
     }
 
     /*!
@@ -187,7 +187,7 @@ public:
 
         if (compIdx == wCompIdx)
             return WettingPhase::molarMass();
-        return NonWettingPhase::molarMass();
+        return NonwettingPhase::molarMass();
     }
 
     /*!
@@ -199,7 +199,7 @@ public:
 
         if (compIdx == wCompIdx)
             return WettingPhase::criticalTemperature();
-        return NonWettingPhase::criticalTemperature();
+        return NonwettingPhase::criticalTemperature();
     };
 
     /*!
@@ -211,7 +211,7 @@ public:
 
         if (compIdx == wCompIdx)
             return WettingPhase::criticalPressure();
-        return NonWettingPhase::criticalPressure();
+        return NonwettingPhase::criticalPressure();
     };
 
     /*!
@@ -223,7 +223,7 @@ public:
 
         if (compIdx == wCompIdx)
             return WettingPhase::acentricFactor();
-        return NonWettingPhase::acentricFactor();
+        return NonwettingPhase::acentricFactor();
     };
 
     /****************************************
@@ -237,7 +237,7 @@ public:
     {
         // two gaseous phases at once do not make sense physically!
         // (But two liquids are fine)
-        assert(WettingPhase::isLiquid() || NonWettingPhase::isLiquid());
+        assert(WettingPhase::isLiquid() || NonwettingPhase::isLiquid());
     }
 
     /*!
@@ -259,7 +259,7 @@ public:
         Scalar pressure = fluidState.pressure(phaseIdx);
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::density(temperature, pressure);
-        return NonWettingPhase::density(temperature, pressure);
+        return NonwettingPhase::density(temperature, pressure);
     }
 
     /*!
@@ -277,7 +277,7 @@ public:
         Scalar pressure = fluidState.pressure(phaseIdx);
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::viscosity(temperature, pressure);
-        return NonWettingPhase::viscosity(temperature, pressure);
+        return NonwettingPhase::viscosity(temperature, pressure);
     }
 
     /*!
@@ -370,7 +370,7 @@ public:
         Scalar pressure = fluidState.pressure(phaseIdx);
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::enthalpy(temperature, pressure);
-        return NonWettingPhase::enthalpy(temperature, pressure);
+        return NonwettingPhase::enthalpy(temperature, pressure);
     }
 
     /*!
@@ -387,7 +387,7 @@ public:
         Scalar pressure = fluidState.pressure(phaseIdx);
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::thermalConductivity(temperature, pressure);
-        return NonWettingPhase::thermalConductivity(temperature, pressure);
+        return NonwettingPhase::thermalConductivity(temperature, pressure);
     }
 
     /*!
@@ -408,7 +408,7 @@ public:
         Scalar pressure = fluidState.pressure(phaseIdx);
         if (phaseIdx == wPhaseIdx)
             return WettingPhase::heatCapacity(temperature, pressure);
-        return NonWettingPhase::heatCapacity(temperature, pressure);
+        return NonwettingPhase::heatCapacity(temperature, pressure);
     }
 };
 
@@ -419,7 +419,7 @@ public:
 namespace Properties {
 NEW_PROP_TAG(Scalar);
 NEW_PROP_TAG(WettingPhase);
-NEW_PROP_TAG(NonWettingPhase);
+NEW_PROP_TAG(NonwettingPhase);
 };
 /*!
  * \brief A non-compositional twophase fluid system.
@@ -432,7 +432,7 @@ template<class TypeTag>
 class TwoPImmiscibleFluidSystem
 : public FluidSystems::TwoPImmiscible<typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)),
                                       typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)),
-                                      typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase))>
+                                      typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase))>
 {};
 #endif
 
diff --git a/dumux/material/old_fluidsystems/2p_system.hh b/dumux/material/old_fluidsystems/2p_system.hh
index 42745d671d9e9651f5afa873d4917e0b73eb9fca..917f1f44625ae8ab22d4c1808df9deb9037fa07e 100644
--- a/dumux/material/old_fluidsystems/2p_system.hh
+++ b/dumux/material/old_fluidsystems/2p_system.hh
@@ -40,7 +40,7 @@ namespace Dumux {
 namespace Properties {
 NEW_PROP_TAG(Scalar);
 NEW_PROP_TAG(WettingPhase);
-NEW_PROP_TAG(NonWettingPhase);
+NEW_PROP_TAG(NonwettingPhase);
 };
 
 
@@ -60,7 +60,7 @@ class FluidSystem2P
     typedef FluidSystem2P<TypeTag> ThisType;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
 public:
 
@@ -93,7 +93,7 @@ public:
     {
         switch (compIdx) {
         case wCompIdx: return WettingPhase::name();
-        case nCompIdx: return NonWettingPhase::name();
+        case nCompIdx: return NonwettingPhase::name();
         };
         DUNE_THROW(Dune::InvalidStateException, "Invalid component index " << compIdx);
     }
@@ -107,7 +107,7 @@ public:
     {
         switch (compIdx) {
         case wCompIdx: return WettingPhase::molarMass();
-        case nCompIdx: return NonWettingPhase::molarMass();
+        case nCompIdx: return NonwettingPhase::molarMass();
         };
         DUNE_THROW(Dune::InvalidStateException, "Invalid component index " << compIdx);
     }
@@ -132,7 +132,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::density(temperature, pressure);
         case nPhaseIdx:
-            return NonWettingPhase::density(temperature, pressure);
+            return NonwettingPhase::density(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -158,7 +158,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::density(temperature, pressure);
         case nPhaseIdx:
-            return NonWettingPhase::density(temperature, pressure);
+            return NonwettingPhase::density(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -183,7 +183,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::viscosity(temperature, pressure);
         case nPhaseIdx:
-            return NonWettingPhase::viscosity(temperature, pressure);
+            return NonwettingPhase::viscosity(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -208,7 +208,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::enthalpy(temperature, pressure);
         case nPhaseIdx:
-            return NonWettingPhase::enthalpy(temperature, pressure);
+            return NonwettingPhase::enthalpy(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
@@ -233,7 +233,7 @@ public:
         case wPhaseIdx:
             return WettingPhase::internalEnergy(temperature, pressure);
         case nPhaseIdx:
-            return NonWettingPhase::internalEnergy(temperature, pressure);
+            return NonwettingPhase::internalEnergy(temperature, pressure);
         }
         DUNE_THROW(Dune::InvalidStateException, "Invalid phase index " << phaseIdx);
     }
diff --git a/test/boxmodels/1p/1ptestproblem.hh b/test/boxmodels/1p/1ptestproblem.hh
index 3cc932a907723f9640f87f15de443304182ffc8f..3161a50143c6f34b5c2862f28f61fbd68a6e40d8 100644
--- a/test/boxmodels/1p/1ptestproblem.hh
+++ b/test/boxmodels/1p/1ptestproblem.hh
@@ -64,7 +64,7 @@ public:
 // Set the grid type
 SET_PROP(OnePTestProblem, Grid)
 {
-    typedef Dune::SGrid<2, 2> type;
+    typedef Dune::SGrid<3, 3> type;
     //typedef Dune::YaspGrid<2> type;
   //typedef Dune::UGGrid<2> type;
   //typedef Dune::ALUSimplexGrid<2,2> type;
diff --git a/test/boxmodels/1p/grids/test_1p_3d.dgf b/test/boxmodels/1p/grids/test_1p_3d.dgf
index fb332164ba0d0065b1fb2f99301ecd1a96fe7a19..59f19dbdf7140702cf176daa1725c34e4a2bfcf4 100644
--- a/test/boxmodels/1p/grids/test_1p_3d.dgf
+++ b/test/boxmodels/1p/grids/test_1p_3d.dgf
@@ -2,7 +2,7 @@ DGF
 Interval
 0 0 0  % first corner 
 1 1 1  % second corner
-10 10 10  % 1 cells in x and 1 in y direction
+20 20 20  % 1 cells in x and 1 in y direction
 # 
 
 BOUNDARYDOMAIN
diff --git a/test/boxmodels/2p/lensproblem.hh b/test/boxmodels/2p/lensproblem.hh
index 99267bf3cf1a389c2aad2577feefd547456e4342..34325e2c316eb347f0fa5252be062cd42ba0ab87 100644
--- a/test/boxmodels/2p/lensproblem.hh
+++ b/test/boxmodels/2p/lensproblem.hh
@@ -80,7 +80,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(LensProblem, NonWettingPhase)
+SET_PROP(LensProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
@@ -160,7 +160,7 @@ class LensProblem : public TwoPProblem<TypeTag>
 
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
     enum {
         numEq = GET_PROP_VALUE(TypeTag, PTAG(NumEq)),
diff --git a/test/boxmodels/2pni/injectionproblem2pni.hh b/test/boxmodels/2pni/injectionproblem2pni.hh
index f82bf695da3e8692226ebcba96fe6e57179a3e4f..d6378b01e7f86de1f3da3032d0ae688d1981a352 100644
--- a/test/boxmodels/2pni/injectionproblem2pni.hh
+++ b/test/boxmodels/2pni/injectionproblem2pni.hh
@@ -89,7 +89,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(InjectionProblem2PNI, NonWettingPhase)
+SET_PROP(InjectionProblem2PNI, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/common/generalproblem/generallensproblem.hh b/test/common/generalproblem/generallensproblem.hh
index ce6028bfd74c7c952dbfcbc9a7853dcbbe23a517..cbc4afb42bc896c36c27392fc8981bfa987249a8 100644
--- a/test/common/generalproblem/generallensproblem.hh
+++ b/test/common/generalproblem/generallensproblem.hh
@@ -93,7 +93,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(GeneralLensProblem, NonWettingPhase)
+SET_PROP(GeneralLensProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
@@ -206,7 +206,7 @@ class GeneralLensProblem : public GET_PROP_TYPE(TypeTag, PTAG(ProblemBaseClass))
 
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
     enum {
         numEq = GET_PROP_VALUE(TypeTag, PTAG(NumEq)),
diff --git a/test/decoupled/1p/test_diffusion_problem.hh b/test/decoupled/1p/test_diffusion_problem.hh
index 0d3b58ab78dbb3e7e445c9158fd454e1e6ee02d5..d21eae87a23d482ccc7fc414ec58f3241272c44e 100644
--- a/test/decoupled/1p/test_diffusion_problem.hh
+++ b/test/decoupled/1p/test_diffusion_problem.hh
@@ -80,7 +80,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(DiffusionTestProblem, NonWettingPhase)
+SET_PROP(DiffusionTestProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2p/test_impes_problem.hh b/test/decoupled/2p/test_impes_problem.hh
index 7c647c877c5eb5b2cd5a63381da12eba128c4526..7b4071688c5127ced7db73fe7edf696a657f2420 100644
--- a/test/decoupled/2p/test_impes_problem.hh
+++ b/test/decoupled/2p/test_impes_problem.hh
@@ -98,7 +98,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(IMPESTestProblem, NonWettingPhase)
+SET_PROP(IMPESTestProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2p/test_transport_problem.hh b/test/decoupled/2p/test_transport_problem.hh
index 3f7a191779004a26a6cf71368e2d2181757251b0..5461f666fd3b427326e61c49605704f6e05706ec 100644
--- a/test/decoupled/2p/test_transport_problem.hh
+++ b/test/decoupled/2p/test_transport_problem.hh
@@ -83,7 +83,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TransportTestProblem, NonWettingPhase)
+SET_PROP(TransportTestProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/test/decoupled/2p2c/test_multiphysics2p2cproblem.hh b/test/decoupled/2p2c/test_multiphysics2p2cproblem.hh
index 9dc6bba0be0464099364782330ab5433edc89b5f..864ad48b71a8044a5f50d3f4cf79bae76a78d313 100644
--- a/test/decoupled/2p2c/test_multiphysics2p2cproblem.hh
+++ b/test/decoupled/2p2c/test_multiphysics2p2cproblem.hh
@@ -37,7 +37,7 @@
 #include <dune/grid/sgrid.hh>
 
 // fluid properties
-//#include <dumux/material/fluidsystems/brine_co2_system.hh>
+//#include <dumux/material/old_fluidsystems/brine_co2_system.hh>
 #include <dumux/material/old_fluidsystems/h2o_n2_system.hh>
 
 #include <dumux/decoupled/2p2c/2p2cproblem.hh>
diff --git a/test/decoupled/2padaptive/test_impes_adaptive_problem.hh b/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
index e2618b12158c0316a6209195ae6815d14cf5441d..72588236764ef7c5f57b0d373fb23ee772346ee7 100644
--- a/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
+++ b/test/decoupled/2padaptive/test_impes_adaptive_problem.hh
@@ -97,7 +97,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TestIMPESAdaptiveProblem, NonWettingPhase)
+SET_PROP(TestIMPESAdaptiveProblem, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/tutorial/tutorialproblem_coupled.hh b/tutorial/tutorialproblem_coupled.hh
index a86aed85e9bd06cc82a927ab351ff5705c246cee..cb4b9e370bc3c381b4fb7a86b1207bd260399a87 100644
--- a/tutorial/tutorialproblem_coupled.hh
+++ b/tutorial/tutorialproblem_coupled.hh
@@ -85,7 +85,7 @@ public: typedef Dumux::LiquidPhase<Scalar, Dumux::H2O<Scalar> > type; /*@\label{
 };
 
 // Set the non-wetting phase
-SET_PROP(TutorialProblemCoupled, NonWettingPhase)
+SET_PROP(TutorialProblemCoupled, NonwettingPhase)
 {
 private: typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
 public: typedef Dumux::LiquidPhase<Scalar, Dumux::Oil<Scalar> > type; /*@\label{tutorial-coupled:nonwettingPhase}@*/
diff --git a/tutorial/tutorialproblem_decoupled.hh b/tutorial/tutorialproblem_decoupled.hh
index c8224db07771f3fddfe13508fea423a8602c1d87..b994eb300eab5a4cd3cfb34b54dd41cc3edb6b23 100644
--- a/tutorial/tutorialproblem_decoupled.hh
+++ b/tutorial/tutorialproblem_decoupled.hh
@@ -95,7 +95,7 @@ public:
 };
 
 // Set the non-wetting phase
-SET_PROP(TutorialProblemDecoupled, NonWettingPhase)
+SET_PROP(TutorialProblemDecoupled, NonwettingPhase)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
diff --git a/dumux/boxmodels/richards/richardspropertydefaults.hh b/dumux/boxmodels/richards/richardspropertydefaults.hh
index b4948ac6343949251b686ebf73c167222c75e347..5fc78d5aa7c25c9b457c9c7599b8f5be019c109d 100644
--- a/dumux/boxmodels/richards/richardspropertydefaults.hh
+++ b/dumux/boxmodels/richards/richardspropertydefaults.hh
@@ -119,7 +119,7 @@ public:
  * specified by the problem for the Richards model to work because the
  * Richards model does not conserve the non-wetting phase.
  */
-SET_PROP(BoxRichards, NonWettingPhase)
+SET_PROP(BoxRichards, NonwettingPhase)
 { private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
 public:
@@ -131,7 +131,7 @@ public:
  *
  * By default this uses the immiscible twophase fluid system. The
  * actual fluids used are specified using in the problem definition by
  * the WettingPhase and NonWettingPhase properties. Be aware that
  * using different fluid systems in conjunction with the Richards
  * model only makes very limited sense.
  */
@@ -139,12 +139,12 @@ SET_PROP(BoxRichards, FluidSystem)
 { private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(Scalar)) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(WettingPhase)) WettingPhase;
-    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonWettingPhase)) NonWettingPhase;
+    typedef typename GET_PROP_TYPE(TypeTag, PTAG(NonwettingPhase)) NonwettingPhase;
 
 public:
     typedef Dumux::FluidSystems::TwoPImmiscible<Scalar,
                                                 WettingPhase,
-                                                NonWettingPhase> type;
+                                                NonwettingPhase> type;
 };
 
 // \}
@@ -131,7 +131,7 @@ public:
  * By default this uses the immiscible twophase fluid system. The
  * actual fluids used are specified using in the problem definition by
- * the WettingPhase and NonWettingPhase properties. Be aware that
+ * the WettingPhase and NonwettingPhase properties. Be aware that
  * using different fluid systems in conjunction with the Richards
  * model only makes very limited sense.